import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_ec2._jsii
import aws_cdk.core._jsii
import aws_cdk.custom_resources._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/aws-globalaccelerator",
    "1.66.0",
    __name__[0:-6],
    "aws-globalaccelerator@1.66.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
